% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/causalsim-package.R
\docType{package}
\name{causalsim-package}
\alias{causalsim-package}
\title{causalsim: Simulation-Ready Causal Data Generating Processes}
\description{
Construct, simulate, and evaluate causal data generating processes (DGPs)
with known ground truth. Covariate roles (confounder, effect modifier,
noise) and heterogeneous treatment effects are first-class concepts, and
estimator performance is summarised with bias, RMSE, confidence-interval
coverage, and power. Results are returned as plain data frames for further
analysis or plotting.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://chaycereed.github.io/causalsim/}
  \item \url{https://github.com/chaycereed/causalsim}
  \item Report bugs at \url{https://github.com/chaycereed/causalsim/issues}
}

}
\author{
\strong{Maintainer}: Chayce Reed \email{Chayce.Reed.HSE@dartmouth.edu}

}
\keyword{internal}
